function cl_perm = bal_perm (seq_samp)
%% BAL_PERM divides an experiment permutation in two classes.
%
% CL_PERM = BAL_PERM (SEQ_SAMP) searches among all possible permutations
% SEQ_SAMP for a permutation where the class design will have two
% different symbols.
%
% VALUE
%       CL_PERM : a design vector for permutations having at least two
%       different elements.

global mat_samp

ind_end = length (seq_samp) - 1;

for i = 1:ind_end
    all_perm = mat_samp (seq_samp (i):(seq_samp (i+1) - 1), :);
    
    nrow = size (all_perm, 1);
    
    rnd_ind = randperm (nrow);
    
    for j = 1:nrow
        cl_perm = all_perm (rnd_ind (j), :);
        
        if length (unique (cl_perm)) ~= 1
            return;
        end
    end
end

error ('bal_perm:unfound', 'Something is wrong with the gene classes.\n\n');
end

