function s_zero = fudge_factor (r, s)
%% FUDGE_FACTOR determines the fudge factor.
%
% S_ZERO = FUDGE_FACTOR (R, S) returns the fudge factor S_ZERO computed
% based on the numerator R and the denominator S of a statistical test's
% computing expression.
%
% VALUE
%       S_ZERO : the computed fudge factor.

global s_alpha include_zero

if (max (s_alpha) > 1) || (min (s_alpha) < 0)
    error ('fudge:bad_input', 'alpha has to be between 0 and 1.\n\n');
end

if length (s_alpha) == 1
    s_zero = real (quantile (s, s_alpha));
    return;
end

fudge_quan = real (quantile (s, s_alpha));

if include_zero == 1
    fudge_quan = [0 fudge_quan];
end

n_alpha = length (fudge_quan);
s_len = length (s);

d_mat = zeros (s_len, n_alpha);
for i = 1:s_len
    for j = 1:n_alpha
        d_mat (i, j) = r (i) / (s (i) + fudge_quan (j));
    end
end

n_uni_s = length (unique (s));

if n_uni_s < 25
    error ('fudge:few_genes', strcat ('For the computation of the fugde ',...
        'factor, there should be at least 25 genes with differing standard',...
        ' deviations.\n'));
end

if n_uni_s > 500
    n_int = 101;
else
    n_int = floor (n_uni_s / 5);
end

% (to - from) / (length - 1)
buff_foot = 1 / (n_int - 1);
quan = real (quantile (s, 0:buff_foot:1));

%round to the 8th digit after the comma
quan = floor ((quan * power (10, 8))) / power (10, 8);
quan = unique (quan);

n_int = length (quan);

len_s = length (s);
s_sort = sort (s);
int_s = zeros (1, len_s);

for i = 1:len_s
    j = 2;
    while (s_sort (i) > quan (j)) && (j < n_int)
        j = j + 1;
    end
    
    int_s (i) = j - 1;
end

mad_mat = zeros (n_int - 1, size (d_mat, 2));

for i = 1:n_int - 1
    buff_ind = (int_s == i);
    mad_mat (i, :) = 1.4826 * mad (d_mat (buff_ind, :), 1);
end
mad_mat (isnan (mad_mat)) = 0;

buff_ind = size (mad_mat, 2);
vec_cv = zeros (1, buff_ind);

for i = 1:buff_ind
    vec_cv (i) = std (mad_mat (:, i)) / mean (mad_mat (:, i));
end

which_min = find (vec_cv == min (vec_cv));

if (include_zero == 1) && (which_min == 1)
    s_zero = 0;
    return;
end

fudge_quan = fudge_quan / 10;

buff_ind = find (fudge_quan == 0);
fudge_quan (buff_ind) = [];
vec_cv (buff_ind) = [];

which_min = (vec_cv == min (vec_cv));

s_zero = fudge_quan (which_min);
end
