function mat_fold = get_fold_changes (cl)
%% GET_FOLD_CHANGES computes the observations fold changes.
%
% MAT_FOLD = GET_FOLD_CHANGES (CL) returns the fold changes MAT_FOLD of the
% data divided into classes following the CL design.
%
% VALUE
%       MAT_FOLD : the observations fold changes.

global data R_unlog R_fold use_dm

cl_ids = unique (cl);

if R_fold < 1
    R_fold = 1 / R_fold;
end

if (use_dm == 0) && (R_unlog == 1)
    data = 2 .^ data;
end

d0 = data (:, cl == cl_ids (1));
d1 = data (:, cl == cl_ids (2));

mean0 = mean (d0, 2);
mean1 = mean (d1, 2);

if use_dm == 0
    mean0 (mean0 <= 0) = NaN;
    mean1 (mean1 <= 0) = NaN;
    fold_out = mean1 ./ mean0;
else
    fold_out = 2 .^ (mean1 - mean0);
end

fulfill = zeros (1, length (fold_out));
fulfill (fold_out >= R_fold) = 1;
fulfill (fold_out <= (1 / R_fold)) = 1;

mat_fold = zeros (length (fold_out), 2);
mat_fold (:, 1) = fold_out;
mat_fold (:, 2) = fulfill;
end
