%% Significance Analysis of Microarrays implementation using Matlab
%
% Microarray experiments enable the simultaneous measure of expression
% levels of large amount of genes and have many applications. A widespread
% one is finding set of genes that are differential expressed. Significance
% Analysis of Microarrays (SAM) helps to produce those sets using multiple
% testing techniques. There is unfortunately not yet a public tool enabling
% to do SAM using the Matlab platform. We here define MatSAM, a SAM
% implementation in Matlab, and show that it yields results of high
% confidence comparatively to those obtained by putative tools available in
% the R programming environment. MatSAM can be used in conjunction with
% Matlab Bioinformatics toolbox to perform further analysis. MatSAM is
% based on the BioConductor project package siggenes (Schwender, 2012),
% courtesy to siggenes maintainer' permission.
%
%% Disclaimer
% This is the documentation home page. To browse the API documentation, one
% should use the links provided below.
%
% This is an *_algorithm implementation documentation and not a
% software's_*, that is the documentation here provided does not deal with
% using Matlab or any of its toolboxes. Once one has installed Matlab along
% with the Statistics and Bioinformatics toolboxes, they could use MatSAM
% in the same way as for any set of scripts ran in Matlab.
%
%% Download
% MatSAM source code and supplementary files can be
% <http://www.bioinfoindia.org/MatSAM/MatSAM_Source_Codes.zip found here.>
%
%% Demonstration
% To see a full demonstration of the standard way MatSAM is ran, please
% refer to <SAM_demo.html the demonstration page>.
%
%% Manual pages
%
% <global_args.html GLOBAL_ARGS> declares and defines global arguments.
%
% <sam_input.html SAM_INPUT> reads the raw files containing gene intensities and
% gene names.
%
% <sam_func.html SAM_FUNC> proceeds to the Significance Analysis of Microarrays.
%
% <d_stat_func.html D_STAT_FUNC> corrects the D-scores by the fudge factor.
%
% <purge_nan.html PURGE_NAN> removes all NaNs in the data.
%
% <test_type.html TEST_TYPE> decides which statistical test to launch.
%
% <get_fold_changes.html GET_FOLD_CHANGES> computes the observations fold
% changes.
%
% <statest_num_denum.html STATEST_NUM_DENUM> gives the numerator and the
% denominator of a statistical test.
%
% <fudge_factor.html FUDGE_FACTOR> determines the fudge factor.
%
% <setup_mat_samp.html SETUP_MAT_SAMP> randomly permutes the experiments.
%
% <d_null.html D_NULL> computes D-bar scores and P-values after statistical
% testing the data.
%
% <build_dperm.html BUILD_DPERM> computes D-scores for a given class
% permutation.
%
% <bal_perm.html  BAL_PERM> divides an experiment permutation following
% provided classes design.
%
% <perm_statest_num_denum.html PERM_STATEST_NUM_DENUM> computes the numerator
% and the denominator of the required statistical test.
%
% <pi0_estimation.html PI0_ESTIMATION> estimates the prior that an observation
% is expressed.
%
% <qvalue_cal.html QVALUE_CAL> computes the q-value for each observation.
%
% <ranking.html RANKING> ascendantly ranks the data.
%
% <full_results.html FULL_RESULTS> prints out summary of the SAM results.
%
% <stats_cal.html STATS_CAL> gathers the statistics of the SAM.
%
% <sam_results.html SAM_RESULTS> gathers all the SAM results.
%
% <sam_plot.html SAM_PLOT> yields the SAM Q-Q plot.
%
% <save_sam_results.html SAVE_SAM_RESULTS> writes the SAM results in a file.
%
%% License
%
% MatSAM is inspired by the siggenes package (Schwender, 2012). siggenes is
% a free software distributed under the LGPL version 2 or later
% <licenses/lgpl-3.0.txt (GNU Lesser General Public License).>
%
% MatSAM is distributed under the BSD License, no advertising
% <licenses/bsd.txt (Berkeley Software Distribution).>
%
%% References
%
% * Virginia Goss Tusher, Robert Tibshirani, Gilbert Chu (2001).
% *Significance analysis of microarrays applied to the ionizing radiation
% response.* _Proceedings of the National Academy of Sciences_
% 98(9): 5116-5121.
%
% * Holger Schwender (2012). *siggenes : Multiple testing using SAM and
% Efron's empirical Bayes approaches.* _R package_, version 1.38.0.
%
%% Authors contact
%
% <mailto:eric.nimpaye@gmail.com Eric NIMPAYE>
%
% <mailto:kaissi.ouafae@gmail.com Ouafae KAISSI>
%
% <mailto:tiratharaj@gmail.com Tiratha Raj SINGH>
%
% <mailto:brigitte.vannier@univ-poitiers.fr Brigitte VANNIER>
%
% <mailto:azeibrah@yahoo.com Azeddine IBRAHIMI>
%
% <mailto:amoussa@uae.ac.ma Ahmed MOUSSA>
