function [r, s] = perm_statest_num_denum (data, cl, type_mt)
%% PERM_STATEST_NUM_DENUM computes the numerator and the denominator of the
% required statistical test.
%
% [R, S] = PERM_STATEST_NUM_DENUM (DATA, CL, TYPE_MT) computes the numerator
% and the denominator of the required statistical test, bypassing the NaNs
% removing.
%
% See also STATEST_NUM_DENUM.

global WILC_SIGNED_RANK_STAT WILC_RANK_SUMS_t WILC_RANK_SUMS_t_equalvar...
    WILC_SIGNED_RANK_SCORES F_STAT

if strcmp (type_mt, WILC_RANK_SUMS_t) == 1
    cl_ids = unique (cl);

    % Row means    
    grp1 = data (:, cl == cl_ids (1));
    grp2 = data (:, cl == cl_ids (2));
    avg_grp1 = mean (grp1, 2);
    avg_grp2 = mean (grp2, 2);
    
    %The numerator of the test
    r = avg_grp2 - avg_grp1;
    
    %The denominator of the test
    c1 = size (grp1, 2);
    c2 = size (grp2, 2);
    
    t0 = c1 * (c1 - 1);
    t1 = c2 * (c2 - 1);
    
    sz = size (data, 1);
    s = zeros (sz, 1);
    
    for i = 1:sz
        devi_1 = sum (power (grp1 (i, :) - avg_grp1 (i), 2));
        devi_2 = sum (power (grp2 (i, :) - avg_grp2 (i), 2));
        s (i) = sqrt ((devi_1 / t0) + (devi_2 / t1));
    end
    
elseif strcmp (type_mt, F_STAT) == 1
    error ('code_to_come', 'Sorry, F-stat is not yet implemented.\n');
    
elseif (strcmp (type_mt, WILC_SIGNED_RANK_STAT) == 1) ||...
        (strcmp (type_mt, WILC_SIGNED_RANK_SCORES) == 1)
    error ('code_to_come', 'Sorry, Wilc-sign is not yet implemented.\n');
    
elseif strcmp (type_mt, WILC_RANK_SUMS_t_equalvar) == 1
    error ('code_to_come', 'Sorry, Wilc-Rank-Var-Equal unimplemented.\n');
    
else
    error ('statest:unknown_test', 'The required test is not available.\n');
end
end
