function pi0_estimation (p_value)
%% PI0_ESTIMATION estimates the prior of an observation
%
% PI0_ESTIMATION (P_VALUE) sets the global argument P0 to the prior
% probability of the expression of each observation; its value is inferred
% based on the statistical test P_VALUEs.

global p0 lambda ncs_value

if (sum (lambda >= 1) ~= 0) || (sum (lambda < 0) ~= 0)
    error ('pi0:wrong_lambda', 'lambda has to be between 0 and 1.\n\n');
end
if (strcmp (ncs_value, 'paper') ~= 1) && (strcmp (ncs_value, 'max') ~= 1)
    error ('pi0:wrong_ncs_value', strcat ('ncs_value has to be either ',...
        'paper oder max.\n\n'));
end

le_la = length (lambda);

if strcmp (ncs_value, 'paper') == 1
    ncs_pred = 1;
else
    ncs_pred = max (lambda);
end

vec_p0 = zeros (1, le_la);
for i = 1:le_la
    vec_p0 (i) = mean (p_value (p_value > lambda (i))) ./ (1 - lambda (i));
end

if le_la == 1
    p0 = min ([1, vec_p0]);
    return;
end

p0 = median (spline (lambda, vec_p0, ncs_pred), 1) / 100;

if p0 <= 0
    p0 = vec_p0 (lambda == 0.5);
end
end
