function q_value = qvalue_cal (p_value)
%% QVALUE_CAL computes the q-value for each observation.
%
% Q_VALUE = QVALUE_CAL (P_VALUE) returns the corresponding Q_VALUEs to the
% provided P_VALUEs.
%
% VALUE
%       Q_VALUE : the q-values of all observations.

global p0 q_version

p_na = 0;

if sum (isnan (p_value)) ~= 0
    p_na = find (isnan (p_value));
    p_value (isnan (p_value)) = [];
end

if (q_version ~= 1) && (q_version ~= 2)
    error ('q_values:q_version', strcat ('q_version must be either 1 (for ',...
        'using the FDR) or 2 (pFDR).'));
end

m = length (p_value);

p_sort = sort (p_value);
q_value = (p0 * m) .* p_sort ./ (1:m)';

if q_version == 2
    buff_min = min (min (min (p_sort (p_sort ~= 0)), 10 ^ -15), 10 ^ (-15));
    
    for i = 1:m
        if p_sort (i) ~= 0
            q_value (i) = q_value (i) / ((1 - (1 - p_sort (i))) ^ m);
        else
            q_value (i) = q_value (i) / ((1 - (1 - buff_min)) ^ m);
        end
    end
end

q_value (m) = min (q_value(m), 1);

for i = (m-1):-1:1
    q_value (i) = min (q_value(i), q_value(i+1));
end

buff_qord = ranking (p_value);
q_value (buff_qord) = q_value;

if p_na ~= 0
    q_value (p_na) = NaN;
end
end
