function [d, d_bar, vec_false, p_value, q_value, fold_out, s ] =  sam_func (cl)
%% SAM_FUNC proceeds to the Significance Analysis of Microarrays
%
% ... = SAM_FUNC(CL) does the SAM of the data.
%
% VALUE
%       D : observed expression scores.
%
%       D_BAR : expected expression scores.
%
%       VEC_FALSE : thresholds to choose D scores of expressed observations.
%
%       P_VALUE : p-values.
%
%       Q_VALUE : q-values corresponding to the p-values.
%
%       FOLD_OUT : fold changes.
%
%       S : denominators of the statistical test.
%
% See also D_STAT_FUNC.

global p0 q_version

fprintf ('Doing statistical test ...\n\n');
[d, d_bar, p_value, vec_false, fold_out, s] = d_stat_func (cl);

if isnan (p0)
    fprintf (strcat ('Estimating the prior probability that a gene is',...
        ' differential expressed ...\n\n'));
    pi0_estimation (p_value);
end

if (q_version == 1) || (q_version == 2)
    fprintf ('\n\nComputing the q-value for each gene ...\n\n');
    q_value = qvalue_cal (p_value);
else
    q_value = 0;
end
end
