function sam_plot (d, d_bar, delta, vec_false)
%% SAM_PLOT yields a plot summarizing the SAM results.
%
% SAM_PLOT (D, D_BAR, DELTA, VEC_FALSE) computes the observed D values and
% plots them against D_BAR , the expected D values. It finds the expressed
% observations on the basis of the thresholds comprised in VEC_FALSE.

d_sort = sort (d);

pl_title = sprintf ('SAM Plot for Delta = %.1f', delta);
x_label = 'Expected d(i) values';
y_label = 'Observed d(i) values';

fprintf (strcat ('Determining Delta, prior probability, false called',...
    ' genes, FDR, low and up cut-offs ...\n\n'));
mat_fdr = stats_cal (d, d_bar, vec_false, delta);

%cutup
d_up = find (d_sort >= mat_fdr (1, 7));

%cutlow
d_low = find (d_sort <= mat_fdr (1, 6));

figure

if isempty (d_up) && isempty (d_low)
    plot (d_bar, d_sort, '.k')
    title (pl_title)
    
else
    sz_d = length (d_sort);
    
    len_up = length (d_up);
    len_low = length (d_low);
    excl_ind = zeros (1, len_up + len_low);
    
    for i = 1:len_up
        excl_ind (i) = d_up (i);
    end
    for i = 1:len_low
        excl_ind (i + len_up) = d_low (i);
    end
    
    mid_ind = zeros (1, sz_d - length (excl_ind));
    j = 1;
    for i = 1:sz_d
        if sum (excl_ind == i) == 0
            mid_ind (j) = i;
            j = j + 1;
        end
    end
    
    plot (d_bar (mid_ind), d_sort (mid_ind), '.k');
    title (pl_title)
    
    hold on
    plot (d_bar (d_up), d_sort (d_up), 'diamondr');
    
    hold on
    plot (d_bar (d_low), d_sort (d_low), 'squarer');
end

xlabel (x_label)
ylabel (y_label)

hold on
buff_refl = refline (1, 0);
set (buff_refl, 'Color', 'g');

hold on
buff_refl = refline (1, delta);
set (buff_refl, 'Color', 'k', 'LineStyle', '--');

hold on
buff_refl = refline (1, -delta);
set (buff_refl, 'Color', 'k', 'LineStyle', '--');

if ~isinf (mat_fdr (1, 7))
    hold on
    buff_refl = refline ([0, mat_fdr(1,7)]);
    set (buff_refl, 'Color', 'm', 'LineStyle', '-.');
end

if ~isinf (mat_fdr (1, 6))
    hold on
    buff_refl = refline ([0, mat_fdr(1,6)]);
    set (buff_refl, 'Color', 'm', 'LineStyle', '-.');
end
end
