function [mat_sig, mat_sig_hdr, called_names, mat_fdr] = sam_results (...
    delta, d, d_bar, vec_false, s, p_value, q_value, fold_out)
%% SAM_RESULTS gathers all the SAM results.
%
% MAT_SIG = SAM_RESULTS (...) puts in MAT_SIG the significant observations
% and all their metrics.
%
% [MAT_SIG, MAT_SIG_HDR] = SAM_RESULTS (...) returns in MAT_SIG_HDR the
% header of the significant observations.
%
% [MAT_SIG, MAT_SIG_HDR, CALLED_NAMES] = SAM_RESULTS (...) puts the called
% observations' names in CALLED_NAMES .
%
% [MAT_SIG, MAT_SIG_HDR, CALLED_NAMES, MAT_FDR] = SAM_RESULTS (...) summarizes
% the called observations' metrics in MAT_FDR.
%
% VALUE
%       MAT_SIG : expressed observations.
%
%       MAT_SIG_HDR : header of the expressed observations' container.
%
%       CALLED_NAMES : names or identifiers of the expressed observations.
%
%       MAT_FDR : all the metrics of the expressed observations.
%
% See also SAM_FUNC.

global gene_names

if length (delta) ~= 1
    error ('printing:wrong_delta', 'Delta must be a single numeric value.\n');
end

fprintf (strcat ('Determining Delta, prior probability, false called',...
    ' genes, FDR, low and up cut-offs ...\n\n'));
mat_fdr = stats_cal (d, d_bar, vec_false, delta);

%greater than cutup, lower than cutlow
sig_genes_inf = find (d <= mat_fdr (:, 6));
sig_genes_pos = find (d >= mat_fdr (:, 7));

len_inf = length (sig_genes_inf);
len_pos = length (sig_genes_pos);
sig_genes = zeros (1, len_inf + len_pos);

for i = 1:len_inf
    sig_genes (i) = sig_genes_inf (i);
end
for i = 1:len_pos
    sig_genes (i + len_inf) = sig_genes_pos (i);
end

if isempty (sig_genes) == 1
    error ('printing:no_gene', strcat ('There is no gene found with delta',...
        ' equals to %g.\nPlease, try again with another value of delta.\n\n'),...
        delta);
end

mat_sig_hdr = {'Row', 'D-val', 'Std-dev', 'Raw_P-val', 'Q-val', 'Fold-Change'};

called_names = gene_names (sig_genes);

mat_sig = zeros (length (sig_genes), 7);

mat_sig (:, 1) = sig_genes;
mat_sig (:, 2) = d (sig_genes);
mat_sig (:, 3) = s (sig_genes);
mat_sig (:, 4) = p_value (sig_genes);
mat_sig (:, 5) = q_value (sig_genes);
mat_sig (:, 6) = fold_out (sig_genes);
end
