function setup_mat_samp (cl, type_mt)
%% SETUP_MAT_SAMP randomly permutes the experiments.
%
% SETUP_MAT_SAMP (CL, TYPE_MT) stores in the global argument MAT_SAMP all
% the possible permutations of the experiments on the data. The experiments
% are divided into classes following the CL design and the
% TYPE_MT statistical test.

global B mat_samp B_more B_max rand_seed  WILC_SIGNED_RANK_STAT...
    WILC_SIGNED_RANK_SCORES F_STAT

custom_seed = 0;
if isnan (rand_seed) == 0
    custom_seed = 1;
end

n_cl = length (cl);
ncol = size (mat_samp, 2);

if sum (sum (mat_samp == 0)) ~= 0
    is_matsamp_null = 1;
else
    is_matsamp_null = 0;
end

if is_matsamp_null == 0
    if (strcmp (type_mt, WILC_SIGNED_RANK_STAT) == 1) ||...
            (strcmp (type_mt, WILC_SIGNED_RANK_SCORES) == 1)
        error ('code_to_come', 'The test is not yet implemented.\n\n');
    end
    
    if n_cl ~= ncol
        error ('perm:wrong_mat', strcat ('The number of columns of mat.samp',...
            ' must be equal to the length of cl.\n\n'));
    end
    
    if strcmp (type_mt, F_STAT) == 1
        error ('code_to_come', 'The test is not yet implemented.\n\n');
    end
    return;
end

if (B < 0) || (floor (B) ~= B)
    error ('perm:number_perm', 'B must be a positive integer.\n\n');
end
if (B_more < 0) || (B_more > 1)
    error ('perm:number_perm', 'B_more must be between 0 and 1.\n\n');
end
if( B_max < 0) || (floor (B_max) ~= B_max)
    error ('perm:number_perm', 'B_max must be a positive integer.\n\n');
end

% Compute the number of permutations
if (strcmp (type_mt, WILC_SIGNED_RANK_STAT) == 1) ||...
        (strcmp (type_mt, WILC_SIGNED_RANK_SCORES) == 1)
    B_full = round (2 ^ (n_cl / 2));
else
    B_full = round (exp (gammaln (n_cl + 1)));
    %or B_full = factorial (n_cl);
end

if B == 0
    B = B_full;
end

B_large = ceil (B * (1 + B_more));

if B_large >= B_full
    if custom_seed == 1
        safe_rnd = max ([0 rand_seed]);
        rnd_stream = RandStream.create ('mcg16807', 'seed', safe_rnd);
        mat_samp= ceil ((rand (rnd_stream, B_large, n_cl) * n_cl) + eps);
        
    else
        buffer_perm = ceil ((rand (B, n_cl) * n_cl) + eps);
        
        [nrow, ncol] = size (buffer_perm);
        fin_perms = zeros (nrow, ncol);
        for i = 1:nrow
            fin_perms (i, :) = cl (buffer_perm (i, :));
        end
        
        mat_samp = [cl'; fin_perms];
    end
    
    return;
    
elseif B_max >= B_full
    fprintf (strcat ('\tWe are doing %i complete permutations and randomly',...
        ' select %i of them.\n'), 2 ^ (n_cl / 2), B);
    
    if (strcmp (type_mt, WILC_SIGNED_RANK_STAT) == 1) ||...
            (strcmp (type_mt, WILC_SIGNED_RANK_SCORES) == 1)
        error ('perm:classes_perm', 'The test is not yet supported.\n\n');
        
    elseif custom_seed == 1
        safe_rnd = max ([0 rand_seed]);
        rnd_stream = RandStream.create ('mcg16807', 'seed', safe_rnd);
        mat_samp = ceil ((rand (rnd_stream, B, n_cl) * n_cl) + eps);
        
    else
        buffer_perm = ceil ((rand (B, n_cl) * n_cl) + eps);
        
        [nrow, ncol] = size (buffer_perm);
        mat_samp = zeros (nrow, ncol);
        
        for i = 1:nrow
            mat_samp (i, :) = cl (buffer_perm (i, :));
        end
    end

    return;
end

if (strcmp (type_mt, WILC_SIGNED_RANK_STAT) == 1) ||...
        (strcmp (type_mt, WILC_SIGNED_RANK_SCORES) == 1)
    % 2 permutations
    error ('code_to_come', 'The test is not yet supported.\n\n');
else
    buffer_perm = ceil ((rand (B, n_cl) * n_cl) + eps);
    
    [nrow, ncol] = size (buffer_perm);
    mat_samp = zeros (nrow, ncol);
    
    for i = 1:nrow
        mat_samp (i, :) = cl (buffer_perm (i, :));
    end
end
end
